@@ -4,6 +4,7 @@ from .mpv import Mpv
 from .neovim import Neovim
 from .qutebrowser import Qutebrowser
 from .rofi import Rofi
+from .sioyek import Sioyek
 from .sxhkd import Sxhkd
 from .sxiv import Sxiv
 from .termite import Termite
@@ -21,6 +22,7 @@ __all__ = [
     "Rofi",
     "Sxhkd",
     "Sxiv",
+    "Sioyek",
     "Termite",
     "Vim",
     "Vimiv",
